Update standard executable trusting patch to use the new upstream macro instead of individual inline replacements.

ubuntu/disco
Simon Quigley 5 years ago
parent 3fa1ce108c
commit cb42c7b187

7
debian/changelog vendored

@ -1,3 +1,10 @@
libfm-qt (0.14.0-0ubuntu4) UNRELEASED; urgency=medium
* Update standard executable trusting patch to use the new upstream macro
instead of individual inline replacements.
-- Simon Quigley <tsimonq2@ubuntu.com> Mon, 04 Mar 2019 18:59:59 -0600
libfm-qt (0.14.0-0ubuntu3) disco; urgency=medium
* Fix metadata for trusting executables.

@ -5,45 +5,12 @@ Bug: https://bugs.launchpad.net/bugs/1813687
Last-Update: 2019-01-29
--- a/src/core/fileinfo.cpp
+++ b/src/core/fileinfo.cpp
@@ -10,7 +10,7 @@ const char defaultGFileInfoQueryAttribs[
"access::*,"
"id::filesystem,"
"metadata::emblems,"
- "metadata::trust";
+ "metadata::trusted";
@@ -2,7 +2,7 @@
#include "fileinfo_p.h"
#include <gio/gio.h>
FileInfo::FileInfo() {
// FIXME: initialize numeric data members
@@ -391,8 +391,8 @@ bool FileInfo::isExecutableType() const
bool FileInfo::isTrustable() const {
if(isExecutableType()) {
/* to avoid GIO assertion warning: */
- if(g_file_info_get_attribute_type(inf_.get(), "metadata::trust") == G_FILE_ATTRIBUTE_TYPE_STRING) {
- if(const auto data = g_file_info_get_attribute_string(inf_.get(), "metadata::trust")) {
+ if(g_file_info_get_attribute_type(inf_.get(), "metadata::trusted") == G_FILE_ATTRIBUTE_TYPE_STRING) {
+ if(const auto data = g_file_info_get_attribute_string(inf_.get(), "metadata::trusted")) {
return (strcmp(data, "true") == 0);
}
}
@@ -402,16 +402,16 @@ bool FileInfo::isTrustable() const {
-#define METADATA_TRUST "metadata::trust"
+#define METADATA_TRUST "metadata::trusted"
namespace Fm {
void FileInfo::setTrustable(bool trust) const {
if(!isExecutableType()) {
- return; // "metadata::trust" is only for executables
+ return; // "metadata::trusted" is only for executables
}
GObjectPtr<GFileInfo> info {g_file_info_new()}; // used to set only this attribute
if(trust) {
- g_file_info_set_attribute_string(info.get(), "metadata::trust", "true");
- g_file_info_set_attribute_string(inf_.get(), "metadata::trust", "true");
+ g_file_info_set_attribute_string(info.get(), "metadata::trusted", "true");
+ g_file_info_set_attribute_string(inf_.get(), "metadata::trusted", "true");
}
else {
- g_file_info_set_attribute(info.get(), "metadata::trust", G_FILE_ATTRIBUTE_TYPE_INVALID, nullptr);
- g_file_info_set_attribute(inf_.get(), "metadata::trust", G_FILE_ATTRIBUTE_TYPE_INVALID, nullptr);
+ g_file_info_set_attribute(info.get(), "metadata::trusted", G_FILE_ATTRIBUTE_TYPE_INVALID, nullptr);
+ g_file_info_set_attribute(inf_.get(), "metadata::trusted", G_FILE_ATTRIBUTE_TYPE_INVALID, nullptr);
}
g_file_set_attributes_from_info(path().gfile().get(),
info.get(),

Loading…
Cancel
Save